import 'dayjs/plugin/weekday';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import * as dayjsNs from 'dayjs';
import { Component, Input, Output, EventEmitter, ElementRef, ViewChild, Directive, HostListener, HostBinding, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const colorTypes = {
    red: 0,
    blue: 1,
    green: 2,
    purple: 3,
    brown: 4,
};
colorTypes[colorTypes.red] = 'red';
colorTypes[colorTypes.blue] = 'blue';
colorTypes[colorTypes.green] = 'green';
colorTypes[colorTypes.purple] = 'purple';
colorTypes[colorTypes.brown] = 'brown';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
const selectedDateMode = {
    fromYearPicker: 0,
    fromDateClicked: 1,
};
selectedDateMode[selectedDateMode.fromYearPicker] = 'fromYearPicker';
selectedDateMode[selectedDateMode.fromDateClicked] = 'fromDateClicked';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const dayjs = dayjsNs;
class NgxDotCalendarComponent {
    constructor() {
        this.selectedDate = dayjs(new Date()).format('YYYY-MM-DD');
        this.changeViewOptions = false;
        this.viewCalendar = true;
        this.now = new Date();
        this.format = 'YYYY-MM-DD';
        this.id = '';
        this.idatePickerBinding = '';
        this.sundayHighlight = false;
        this.minYear = 2017;
        this.maxYear = this.now.getFullYear() + 3;
        this.disabled = false;
        this.disableDays = [];
        this.dateContents = [];
        this.getSelectedDate = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.idatePickerBinding !== '') {
            this.selectDate(this.idatePickerBinding);
        }
        this.init();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes['dateContents']) {
            this.init();
        }
    }
    /**
     * @private
     * @return {?}
     */
    init() {
        this.formatDateStr();
        this.setCalendarProps();
        this.renderCalendar();
    }
    /**
     * @private
     * @return {?}
     */
    setCalendarProps() {
        this.monthCalendar = parseInt(this.selectedMonth, 10);
        this.yearCalendar = this.selectedYear;
    }
    /**
     * @return {?}
     */
    renderCalendar() {
        this.monthCalendarStr = dayjs(new Date())
            .set('month', this.monthCalendar - 1)
            .format('MMMM');
        this.dates = this.populateDate();
        this.dates = this.getDateChunk(this.dates, 7);
        this.weeks = Array(this.dates.length)
            .fill(0)
            .map((e, i) => i);
    }
    /**
     * @return {?}
     */
    formatDateStr() {
        console.log(`selectedDate:${this.selectedDate}`);
        this.selectedDay = dayjs(this.selectedDate).format('DD');
        this.selectedDayStr = dayjs(this.selectedDate).format('ddd');
        this.selectedMonth = dayjs(this.selectedDate).format('MM');
        this.selectedMonthStr = dayjs()
            .set('month', parseInt(this.selectedMonth, 10) - 1)
            .format('MMM');
        this.selectedYear = dayjs(this.selectedDate).format('YYYY');
    }
    /**
     * @return {?}
     */
    populateDate() {
        /** @type {?} */
        const lastDate = this.getLastDate();
        /** @type {?} */
        const monthCalendar = this.monthCalendar.toString();
        /** @type {?} */
        const calendarIdentifier = this.yearCalendar + '-' + (monthCalendar.length === 1 ? '0' + monthCalendar : monthCalendar);
        /** @type {?} */
        const calendarDate = Array(lastDate)
            .fill(0)
            .map((e, i) => {
            /** @type {?} */
            const date = (i + 1).toString();
            /** @type {?} */
            const dateStr = calendarIdentifier + '-' + (date.length === 1 ? '0' + date : date);
            /** @type {?} */
            const dayName = dayjs(dateStr).format('dddd');
            // const dayOfWeek = parseInt(dayjs(dateStr).format('e'), 10);
            /** @type {?} */
            const dayOfWeek = dayjs(dateStr).weekday();
            /** @type {?} */
            const arr = this.disableDays;
            /** @type {?} */
            const disabled = dayjs(dateStr) < this.minDate ||
                dayjs(dateStr) > this.maxDate ||
                arr.indexOf(dayOfWeek) !== -1;
            /** @type {?} */
            const contents = this.dateContents
                .filter(item => item.day === dateStr)
                .map(item => {
                return {
                    hasContent: item.hasContent,
                    colorClassName: this.toColorClassName(item.color)
                };
            });
            /** @type {?} */
            let hasContent = false;
            /** @type {?} */
            let colorClassName = '';
            if (contents.length > 0) {
                hasContent = contents[0].hasContent;
                colorClassName = contents[0].colorClassName;
            }
            return [
                (/** @type {?} */ ({
                    day: dayName,
                    date: i + 1,
                    meta: dateStr,
                    disabled: disabled,
                    hasContent: hasContent,
                    colorClassName: colorClassName
                }))
            ];
        });
        /** @type {?} */
        const firstDay = dayjs(calendarIdentifier + '-01').format('dddd');
        /** @type {?} */
        const lastDay = dayjs(calendarIdentifier + '-' + lastDate).format('dddd');
        switch (firstDay) {
            case 'Monday':
                calendarDate.unshift([null]);
                break;
            case 'Tuesday':
                calendarDate.unshift([null], [null]);
                break;
            case 'Wednesday':
                calendarDate.unshift([null], [null], [null]);
                break;
            case 'Thursday':
                calendarDate.unshift([null], [null], [null], [null]);
                break;
            case 'Friday':
                calendarDate.unshift([null], [null], [null], [null], [null]);
                break;
            case 'Saturday':
                calendarDate.unshift([null], [null], [null], [null], [null], [null]);
                break;
        }
        switch (lastDay) {
            case 'Friday':
                calendarDate.push([null]);
                break;
            case 'Thursday':
                calendarDate.push([null], [null]);
                break;
            case 'Wednesday':
                calendarDate.push([null], [null], [null]);
                break;
            case 'Tuesday':
                calendarDate.push([null], [null], [null], [null]);
                break;
            case 'Monday':
                calendarDate.push([null], [null], [null], [null], [null]);
                break;
            case 'Sunday':
                calendarDate.push([null], [null], [null], [null], [null], [null]);
                break;
        }
        return calendarDate;
    }
    /**
     * @return {?}
     */
    getLastDate() {
        return parseInt(dayjs(new Date(+this.yearCalendar, 0, 31))
            .set('month', this.monthCalendar - 1)
            .format('DD'), 10);
    }
    // Split array of dates into chunk
    /**
     * @private
     * @param {?} date
     * @param {?} size
     * @return {?}
     */
    getDateChunk(date, size) {
        /** @type {?} */
        const results = [];
        while (date.length) {
            results.push(date.splice(0, size));
        }
        return results;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    selectDate(event) {
        this.selectedDateInner(event);
        /** @type {?} */
        const context = {
            selectedDate: this.dateOutput,
            selectedDateMode: selectedDateMode.fromDateClicked
        };
        // Emit selection event
        this.getSelectedDate.emit(context);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    selectDate2(event) {
        this.selectedDateInner(event);
        /** @type {?} */
        const context = {
            selectedDate: this.dateOutput,
            selectedDateMode: selectedDateMode.fromYearPicker
        };
        // Emit selection event
        this.getSelectedDate.emit(context);
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    selectedDateInner(event) {
        this.selectedDate = dayjs(event).format('YYYY-MM-DD');
        this.formatDateStr();
        this.dateOutput = dayjs(this.selectedDate).format(this.format);
    }
    /**
     * @param {?} direction
     * @return {?}
     */
    changeCalendar(direction) {
        if (direction === 'prev') {
            if (this.monthCalendar === 1) {
                /** @type {?} */
                const yearCalendar = parseInt(this.yearCalendar, 10) - 1;
                this.yearCalendar = yearCalendar.toString();
                this.monthCalendar = 12;
            }
            else {
                this.monthCalendar -= 1;
            }
        }
        if (direction === 'next') {
            if (this.monthCalendar === 12) {
                /** @type {?} */
                const yearCalendar = parseInt(this.yearCalendar, 10) + 1;
                this.yearCalendar = yearCalendar.toString();
                this.monthCalendar = 1;
            }
            else {
                this.monthCalendar += 1;
            }
        }
        this.formatDateStr();
        this.renderCalendar();
    }
    /**
     * @return {?}
     */
    viewOptions() {
        this.changeViewOptions = !this.changeViewOptions;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    viewBack(event) {
        this.selectDate2(event);
        this.setCalendarProps();
        this.renderCalendar();
        this.viewOptions();
    }
    /**
     * @param {?} color
     * @return {?}
     */
    toColorClassName(color) {
        return `circle-${colorTypes[color]}`;
    }
}
NgxDotCalendarComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'ngx-dot-calendar',
                template: "<div class=\"idatepicker-wrapper\">\r\n  <div class=\"inner-wrapper\" [ngClass]=\"['inner-wrapper']\"></div>\r\n  <div>\r\n    <hr [ngClass]=\"{ disabled: disabled }\" />\r\n    <div\r\n      [ngClass]=\"['idatepicker-dialog-wrapper', viewCalendar ? 'active' : '']\"\r\n    >\r\n      <div class=\"idatepicker-dialog-wrapper-inner\" *ngIf=\"viewCalendar\">\r\n        <div class=\"idatepicker-dialog-wrapper-container\">\r\n          <!--  <div class=\"idatepicker-dialog-wrapper-container-left\">\r\n            <div>\r\n              <div>\r\n                <div style=\"cursor: pointer;\">{{selectedYear}}</div>\r\n              </div>\r\n            </div>\r\n            <div>\r\n              <div>\r\n                <div style=\"cursor: default; width: 100%; display: block;\">{{selectedDayStr}}, {{selectedMonthStr}} {{selectedDay}}</div>\r\n              </div>\r\n            </div>\r\n          </div>-->\r\n          <div class=\"idatepicker-dialog-wrapper-container-right\">\r\n            <div class=\"idatepicker-dialog-date\">\r\n              <div class=\"idatepicker-dialog-date-select\">\r\n                <div>\r\n                  <div>\r\n                    <div>\r\n                      <span (click)=\"viewOptions()\">\r\n                        <a>{{ monthCalendarStr }} {{ yearCalendar }}</a>\r\n                      </span>\r\n                    </div>\r\n                  </div>\r\n                </div>\r\n                <button\r\n                  *ngIf=\"changeViewOptions === false\"\r\n                  tabindex=\"0\"\r\n                  type=\"button\"\r\n                  (click)=\"changeCalendar('prev')\"\r\n                >\r\n                  <div>\r\n                    <svg>\r\n                      <path\r\n                        d=\"M15.41 7.41L14 6l-6 6 6 6 1.41-1.41L10.83 12z\"\r\n                      ></path>\r\n                    </svg>\r\n                  </div>\r\n                </button>\r\n                <button\r\n                  *ngIf=\"changeViewOptions === false\"\r\n                  tabindex=\"0\"\r\n                  type=\"button\"\r\n                  (click)=\"changeCalendar('next')\"\r\n                >\r\n                  <div>\r\n                    <svg>\r\n                      <path\r\n                        d=\"M10 6L8.59 7.41 13.17 12l-4.58 4.59L10 18l6-6z\"\r\n                      ></path>\r\n                    </svg>\r\n                  </div>\r\n                </button>\r\n              </div>\r\n              <ngx-dot-calendar-dates\r\n                *ngIf=\"changeViewOptions === false\"\r\n                [weeks]=\"weeks\"\r\n                [dates]=\"dates\"\r\n                [selectedDate]=\"selectedDate\"\r\n                [sundayHighlight]=\"sundayHighlight\"\r\n                (setSelectedDate)=\"selectDate($event)\"\r\n              >\r\n              </ngx-dot-calendar-dates>\r\n              <ngx-dot-calendar-years\r\n                [yearCalendar]=\"yearCalendar\"\r\n                [minYear]=\"minYear\"\r\n                [maxYear]=\"maxYear\"\r\n                (showCalendar)=\"viewBack($event)\"\r\n                *ngIf=\"changeViewOptions === true\"\r\n              >\r\n              </ngx-dot-calendar-years>\r\n            </div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                styles: [".idatepicker-wrapper{font-size:16px;line-height:24px;height:48px;display:inline-block;position:relative;background-color:transparent;font-family:Roboto,sans-serif;transition:height .2s cubic-bezier(.23,1,.32,1);cursor:auto}.idatepicker-wrapper .inner-wrapper{position:absolute;opacity:1;margin-left:90%;z-index:1;color:rgba(0,0,0,.298039);transition:450ms cubic-bezier(.23,1,.32,1);bottom:12px}.idatepicker-wrapper .input{padding:0;position:relative;height:100%;width:100%;border:none;outline:0;background-color:rgba(0,0,0,0);color:rgba(0,0,0,.870588);font-size:inherit;font-family:inherit;-webkit-tap-highlight-color:transparent;-webkit-appearance:textfield}.idatepicker-wrapper .input.disabled{color:#b4b4b4;cursor:no-drop}.idatepicker-wrapper div:last-child hr{box-sizing:content-box;margin:0;position:absolute;width:100%;bottom:8px}.idatepicker-wrapper div:last-child hr:first-child{border-color:#e1e1e1;border-top:none;border-left:none;border-right:none}.idatepicker-wrapper div:last-child hr:first-child.disabled{border-bottom:2px dotted rgba(0,0,0,.298039)}.idatepicker-wrapper div:last-child hr:last-child{border-color:#00bcd4;border-top:none;border-left:none;border-right:none;-webkit-transform:scaleX(0);transform:scaleX(0)}.idatepicker-dialog-wrapper{z-index:2000;opacity:0}.idatepicker-dialog-wrapper.active{opacity:1;transition:450ms ease-in-out}.idatepicker-dialog-wrapper-inner{color:rgba(0,0,0,.870588);background-color:#fff;transition:transform 450ms cubic-bezier(.23,1,.32,1),opacity 450ms cubic-bezier(.23,1,.32,1),-webkit-transform 450ms cubic-bezier(.23,1,.32,1);box-sizing:border-box;font-family:Roboto,sans-serif;-webkit-tap-highlight-color:transparent;box-shadow:rgba(0,0,0,.117647) 0 1px 6px,rgba(0,0,0,.117647) 0 1px 4px;border-radius:2px;z-index:2100;opacity:1;-webkit-transform:scaleY(1);transform:scaleY(1);-webkit-transform-origin:left top 0;transform-origin:left top 0;max-height:279px;padding:0;min-height:330px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container{color:rgba(0,0,0,.870588);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}@media all and (min-width:960px){.idatepicker-dialog-wrapper-inner{min-width:768px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container{width:768px}}@media all and (min-width:760px) and (max-width:959px){.idatepicker-dialog-wrapper-inner{min-width:668px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container{width:668px}}@media all and (min-width:480px) and (max-width:759px){.idatepicker-dialog-wrapper-inner{min-width:475px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container{width:475px}}@media all and (max-width:479px){.idatepicker-dialog-wrapper-inner{min-width:300px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container{width:300px}}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left{height:330px;width:165px;float:left;font-weight:700;display:inline-block;background-color:#0769ad;border-top-left-radius:2px;border-top-right-radius:0;border-bottom-left-radius:2px;color:#fff;padding:20px;box-sizing:border-box}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left>div{position:relative;overflow:hidden;transition:450ms cubic-bezier(.23,1,.32,1);font-weight:500}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left>div:first-child{height:16px;margin:0 0 10px;font-size:16px;line-height:16px;opacity:.7}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left>div:last-child{height:100%;width:100%;display:block;font-size:36px;line-height:36px;opacity:1}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left>div div,.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-left>div:last-child div{height:100%;width:100%;position:absolute;top:0;left:0;transition:transform 450ms cubic-bezier(.23,1,.32,1),opacity 450ms cubic-bezier(.23,1,.32,1),-webkit-transform 450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right{display:flex;flex-direction:column}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date{display:flex;align-content:space-between;justify-content:space-between;flex-direction:column;font-size:12px;font-weight:400;padding:0 8px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select{display:flex;justify-content:space-between;background-color:inherit;height:48px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>button{background:0 0;border:10px;box-sizing:border-box;display:inline-block;-webkit-tap-highlight-color:transparent;cursor:pointer;text-decoration:none;margin:0;outline:0;font-size:0;font-weight:inherit;-webkit-transform:translate(0,0);transform:translate(0,0);position:relative;overflow:visible;height:48px;width:48px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>button>div>svg{display:inline-block;color:rgba(0,0,0,.870588);fill:currentcolor;height:24px;width:24px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>div{position:relative;overflow:hidden;height:100%;width:100%;font-size:14px;font-weight:500;text-align:left}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>div>div{position:absolute;top:0;left:0;height:100%;width:100%;transition:transform 450ms cubic-bezier(.23,1,.32,1),opacity 450ms cubic-bezier(.23,1,.32,1),-webkit-transform 450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>div>div>div{height:inherit;padding-top:12px}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>div>div>div>span{cursor:pointer}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-date .idatepicker-dialog-date-select>div>div>div>span::after{height:24px;width:24px;content:'';position:absolute;color:rgba(0,0,0,.870588);fill:currentcolor;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background:url(\"data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' width='24' height='24' stroke='none'> <path d='M16.59 8.59L12 13.17 7.41 8.59 6 10l6 6 6-6z'></path></svg>\")}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-action{display:flex;flex-direction:row;justify-content:flex-end;margin:0;max-height:48px;padding:0}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-action button{border:10px #0769ad;box-sizing:border-box;display:inline-block;-webkit-tap-highlight-color:transparent;cursor:pointer;text-decoration:none;margin:4px 8px 8px 0;padding:0;outline:0;height:36px;line-height:36px;min-width:64px;color:#fff;transition:450ms cubic-bezier(.23,1,.32,1);border-radius:2px;position:relative;overflow:hidden;background:linear-gradient(to bottom,#0077c8,#006eba);text-align:center;max-height:36px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.idatepicker-dialog-wrapper-inner .idatepicker-dialog-wrapper-container .idatepicker-dialog-wrapper-container-right .idatepicker-dialog-action button>div>span{position:relative;padding-left:16px;padding-right:16px;vertical-align:middle;letter-spacing:0;text-transform:uppercase;font-weight:500;font-size:14px}"]
            }] }
];
/** @nocollapse */
NgxDotCalendarComponent.ctorParameters = () => [];
NgxDotCalendarComponent.propDecorators = {
    format: [{ type: Input }],
    id: [{ type: Input }],
    idatePickerBinding: [{ type: Input }],
    sundayHighlight: [{ type: Input }],
    minYear: [{ type: Input }],
    maxYear: [{ type: Input }],
    disabled: [{ type: Input }],
    disableDays: [{ type: Input }],
    minDate: [{ type: Input }],
    maxDate: [{ type: Input }],
    dateContents: [{ type: Input }],
    getSelectedDate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxDotCalendarDatesComponent {
    constructor() {
        this.setSelectedDate = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.dateSymbol = this.parseWeekDays();
    }
    /**
     * @return {?}
     */
    parseWeekDays() {
        /*const weekDays: string[] = [];
        const d = new Date();
    
        while (d.getDay() > 0) {
          d.setDate(d.getDate() + 1);
        }
    
        while (weekDays.length < 7) {
          weekDays.push(d.toLocaleString(this.locale, { weekday: 'short' }));
          d.setDate(d.getDate() + 1);
        }*/
        return ['S', 'M', 'T', 'W', 'T', 'F', 'S'];
    }
    /**
     * @param {?} date
     * @return {?}
     */
    getIsSelected(date) {
        return date === this.selectedDate;
    }
    /**
     * @param {?} date
     * @return {?}
     */
    selectDate(date) {
        this.setSelectedDate.emit(date);
    }
}
NgxDotCalendarDatesComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'ngx-dot-calendar-dates',
                template: "<div class=\"idatepicker-dialog-date-days\">\r\n  <span *ngFor=\"let symbol of dateSymbol\">{{symbol}}</span>\r\n</div>\r\n<div class=\"idatepicker-dialog-date-dates\">\r\n  <div>\r\n    <div>\r\n      <div *ngFor=\"let w of weeks\">\r\n        <span *ngIf=\"dates[w][0][0] === null\"></span>\r\n        <button (click)=\"!dates[w][0][0].disabled ? selectDate(dates[w][0][0].meta) : null\" *ngIf=\"dates[w][0][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][0][0].meta),\r\n                        'disabled': dates[w][0][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][0][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][0][0].disabled }\">\r\n            {{dates[w][0][0].date}}\r\n          </span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][0][0] && dates[w][0][0].hasContent\" [ngClass]=\"dates[w][0][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][1][0] === null\"></span>\r\n        <button (click)=\"!dates[w][1][0].disabled ? selectDate(dates[w][1][0].meta) : null\" *ngIf=\"dates[w][1][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][1][0].meta),\r\n                        'disabled': dates[w][1][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][1][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][1][0].disabled }\">\r\n            {{dates[w][1][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][1][0] && dates[w][1][0].hasContent\" [ngClass]=\"dates[w][1][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][2][0] === null\"></span>\r\n        <button (click)=\"!dates[w][2][0].disabled ? selectDate(dates[w][2][0].meta) : null\" *ngIf=\"dates[w][2][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][2][0].meta),\r\n                        'disabled': dates[w][2][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][2][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][2][0].disabled }\">{{dates[w][2][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][2][0] && dates[w][2][0].hasContent\" [ngClass]=\"dates[w][2][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][3][0] === null\"></span>\r\n        <button (click)=\"!dates[w][3][0].disabled ? selectDate(dates[w][3][0].meta) : null\" *ngIf=\"dates[w][3][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][3][0].meta),\r\n                        'disabled': dates[w][3][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][3][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][3][0].disabled }\">{{dates[w][3][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][3][0] && dates[w][3][0].hasContent\" [ngClass]=\"dates[w][3][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][4][0] === null\"></span>\r\n        <button (click)=\"!dates[w][4][0].disabled ? selectDate(dates[w][4][0].meta) : null\" *ngIf=\"dates[w][4][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][4][0].meta),\r\n                        'disabled': dates[w][4][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][4][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][4][0].disabled }\">{{dates[w][4][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][4][0] && dates[w][4][0].hasContent\" [ngClass]=\"dates[w][4][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][5][0] === null\"></span>\r\n        <button (click)=\"!dates[w][5][0].disabled ? selectDate(dates[w][5][0].meta) : null\" *ngIf=\"dates[w][5][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][5][0].meta),\r\n                        'disabled': dates[w][5][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][5][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'disabled': dates[w][5][0].disabled }\">{{dates[w][5][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][5][0] && dates[w][5][0].hasContent\" [ngClass]=\"dates[w][5][0].colorClassName\"></span>\r\n        </button>\r\n\r\n        <span *ngIf=\"dates[w][6][0] === null\"></span>\r\n        <button (click)=\"!dates[w][6][0].disabled ? selectDate(dates[w][6][0].meta) : null\" *ngIf=\"dates[w][6][0] !== null\" tabindex=\"0\"\r\n          type=\"button\" idate [ngClass]=\"{\r\n                        'selected-day': getIsSelected(dates[w][6][0].meta),\r\n                        'disabled': dates[w][6][0].disabled\r\n                    }\">\r\n          <div *ngIf=\"!dates[w][6][0].disabled\"></div>\r\n          <span [ngClass]=\"{ 'sunday': sundayHighlight, 'disabled': dates[w][6][0].disabled }\">{{dates[w][6][0].date}}</span>\r\n          <br>\r\n          <span *ngIf=\"dates[w][6][0] && dates[w][6][0].hasContent\" [ngClass]=\"dates[w][6][0].colorClassName\"></span>\r\n        </button>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                styles: [".idatepicker-dialog-date-days{display:flex;flex-direction:row;justify-content:space-between;font-weight:500;height:20px;line-height:15px;opacity:.5;text-align:center}.idatepicker-dialog-date-days span{height:auto;width:calc(100% / 7)}.idatepicker-dialog-date-dates{position:relative;overflow:hidden;height:214px}.idatepicker-dialog-date-dates>div{position:absolute;top:0;left:0;height:100%;width:100%;transition:transform 450ms cubic-bezier(.23,1,.32,1),opacity 450ms cubic-bezier(.23,1,.32,1),-webkit-transform 450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-date-dates>div>div{display:flex;flex-direction:column;justify-content:flex-start;font-weight:400;height:228px;line-height:2;position:relative;text-align:center}.idatepicker-dialog-date-dates>div>div div{display:flex;flex-direction:row;justify-content:space-around;height:34px;margin-bottom:2px}.idatepicker-dialog-date-dates>div>div div span{box-sizing:border-box;font-weight:400;padding:4px 0;position:relative;-webkit-tap-highlight-color:transparent;width:42px}.idatepicker-dialog-date-dates>div>div div button{border:10px;box-sizing:border-box;display:inline-block;font-family:Roboto,sans-serif;-webkit-tap-highlight-color:transparent;cursor:pointer;text-decoration:none;margin:0;padding:4px 0;outline:0;font-size:inherit;font-weight:400;position:relative;width:42px;background:0 0}.idatepicker-dialog-date-dates>div>div div button.disabled{cursor:no-drop}.idatepicker-dialog-date-dates>div>div div button:hover>div{opacity:.6;-webkit-transform:scale(1);transform:scale(1)}.idatepicker-dialog-date-dates>div>div div button:hover>span{color:#fff;cursor:pointer}.idatepicker-dialog-date-dates>div>div div button.selected-day>div{background-color:#0797e1;height:34px;width:34px;position:absolute;top:0;left:4px;border-radius:50%;opacity:1;-webkit-transform:scale(1);transform:scale(1);transition:450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-date-dates>div>div div button.selected-day>span:not(.disabled){color:#fff!important;font-weight:400;position:relative}.idatepicker-dialog-date-dates>div>div div button>span.circle-red{border-radius:50%;width:6px;height:6px;padding:0;position:absolute;left:18px;top:24px;background-color:#e53935}.idatepicker-dialog-date-dates>div>div div button>span.circle-blue{border-radius:50%;width:6px;height:6px;padding:0;position:absolute;left:18px;top:24px;background-color:#2196f3}.idatepicker-dialog-date-dates>div>div div button>span.circle-green{border-radius:50%;width:6px;height:6px;padding:0;position:absolute;left:18px;top:24px;background-color:#4caf50}.idatepicker-dialog-date-dates>div>div div button>span.circle-purple{border-radius:50%;width:6px;height:6px;padding:0;position:absolute;left:18px;top:24px;background-color:#9c27b0}.idatepicker-dialog-date-dates>div>div div button>span.circle-brown{border-radius:50%;width:6px;height:6px;padding:0;position:absolute;left:18px;top:24px;background-color:#795548}.idatepicker-dialog-date-dates>div>div div button>div{background-color:#0797e1;position:absolute;top:0;left:4px;height:34px;width:34px;border-radius:50%;opacity:0;-webkit-transform:scale(0);transform:scale(0);transition:450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-date-dates>div>div div button>span{color:rgba(0,0,0,.870588);font-weight:400;position:relative}.idatepicker-dialog-date-dates>div>div div button>span.sunday{color:#db3335}.idatepicker-dialog-date-dates>div>div div button>span.disabled{color:#d0d0d0;cursor:no-drop}.idatepicker-dialog-date-dates>div>div div button>span.over{color:#fff}"]
            }] }
];
NgxDotCalendarDatesComponent.propDecorators = {
    weeks: [{ type: Input }],
    locale: [{ type: Input }],
    dates: [{ type: Input }],
    selectedDate: [{ type: Input }],
    sundayHighlight: [{ type: Input }],
    setSelectedDate: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const dayjs$1 = dayjsNs;
class NgxDotCalendarYearsComponent {
    constructor() {
        this.showCalendar = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.numberOfyears = Array(this.maxYear - this.minYear + 1)
            .fill(0)
            .map((e, i) => i);
        this.months = Array(12)
            .fill(0)
            .map((e, i) => {
            return {
                val: dayjs$1()
                    .set('month', i)
                    .format('MMM'),
                key: i + 1
            };
        });
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        // bring year calendar to the first view of user
        this.yc.nativeElement.scrollIntoView({
            block: 'start',
            behaviour: 'smooth'
        });
    }
    /**
     * @param {?} year
     * @return {?}
     */
    showMonths(year) {
        this.yearCalendar = year.toString();
    }
    /**
     * @param {?} year
     * @param {?} month
     * @return {?}
     */
    backToCalendar(year, month) {
        /** @type {?} */
        const m_ = month < 10 ? '0' + month.toString() : month.toString();
        /** @type {?} */
        const selectedDate = dayjs$1(year.toString() + '-' + m_ + '-01').format('YYYY-MM-DD');
        this.showCalendar.emit(selectedDate);
    }
}
NgxDotCalendarYearsComponent.decorators = [
    { type: Component, args: [{
                // tslint:disable-next-line:component-selector
                selector: 'ngx-dot-calendar-years',
                template: "<div class=\"idatepicker-dialog-years\">\r\n  <div>\r\n    <div>\r\n      <div *ngFor=\"let y of numberOfyears\">\r\n        <div (click)=\"showMonths(minYear + y)\">\r\n          <div\r\n            #yearCalendarInit\r\n            *ngIf=\"(minYear + y).toString() == yearCalendar\"\r\n          ></div>\r\n          <button tabindex=\"0\" type=\"button\">\r\n            <span>{{ minYear + y }}</span>\r\n          </button>\r\n        </div>\r\n        <div [class.show]=\"minYear + y == yearCalendar\">\r\n          <div *ngFor=\"let m of months\">\r\n            <div (click)=\"backToCalendar(minYear + y, m.key)\">{{ m.val }}</div>\r\n          </div>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                styles: [".idatepicker-dialog-years{height:224px;width:100%;display:flex;justify-content:space-between;flex-direction:column;margin-top:10px;overflow:hidden}.idatepicker-dialog-years>div{background-color:#fff;height:inherit;overflow-x:hidden;overflow-y:scroll;position:relative}.idatepicker-dialog-years>div>div{display:flex;flex-direction:column;justify-content:center;min-height:100%}.idatepicker-dialog-years>div>div>div>div:first-child{background-color:#eee;border:1px solid #fff;cursor:pointer}.idatepicker-dialog-years>div>div>div>div:first-child>button{border:10px;box-sizing:border-box;display:block;-webkit-tap-highlight-color:transparent;text-decoration:none;margin:0 auto;padding:0;outline:0;font-size:14px;font-weight:inherit;position:relative;text-align:center;line-height:inherit;cursor:pointer;background-color:transparent}.idatepicker-dialog-years>div>div>div>div:first-child>button>span{-ms-grid-row-align:center;align-self:center;font-size:16px;font-weight:400;position:relative}.idatepicker-dialog-years>div>div>div>div:last-child{padding:0;margin:0;display:flex;justify-content:space-around;overflow:hidden;opacity:0;max-height:0;transition:.3s ease-in-out}.idatepicker-dialog-years>div>div>div>div:last-child.show{opacity:1;max-height:75px}.idatepicker-dialog-years>div>div>div>div:last-child div{cursor:pointer}.idatepicker-dialog-years>div>div>div>div:last-child div div:hover{background-color:#0797e1;-webkit-transform:scale(1);transform:scale(1);color:#fff;transition:450ms cubic-bezier(.23,1,.32,1)}.idatepicker-dialog-years>div>div>div>div:last-child>div{height:15px;width:50px;padding:5px;font-size:14px;text-align:center}"]
            }] }
];
NgxDotCalendarYearsComponent.propDecorators = {
    yearCalendar: [{ type: Input }],
    minYear: [{ type: Input }],
    maxYear: [{ type: Input }],
    showCalendar: [{ type: Output }],
    yc: [{ type: ViewChild, args: ['yearCalendarInit',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DateHighlight {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.isHover = false;
    }
    /**
     * @return {?}
     */
    onMouseEnter() {
        if (!this.el.nativeElement.classList.contains('disabled')) {
            this.isHover = true;
        }
    }
    /**
     * @return {?}
     */
    onMouseLeave() {
        this.isHover = false;
    }
}
DateHighlight.decorators = [
    { type: Directive, args: [{
                selector: '[idate]'
            },] }
];
/** @nocollapse */
DateHighlight.ctorParameters = () => [
    { type: ElementRef }
];
DateHighlight.propDecorators = {
    isHover: [{ type: HostBinding, args: ['class.hover',] }],
    onMouseEnter: [{ type: HostListener, args: ['mouseenter',] }],
    onMouseLeave: [{ type: HostListener, args: ['mouseleave',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxDotCalendarModule {
}
NgxDotCalendarModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule, FormsModule],
                declarations: [
                    NgxDotCalendarComponent,
                    NgxDotCalendarDatesComponent,
                    NgxDotCalendarYearsComponent,
                    DateHighlight
                ],
                exports: [NgxDotCalendarComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxDotCalendarComponent, NgxDotCalendarModule, colorTypes, NgxDotCalendarDatesComponent as ɵa, NgxDotCalendarYearsComponent as ɵb, DateHighlight as ɵc };

//# sourceMappingURL=ngx-dot-calendar.js.map